@@ -3,16 +3,16 @@
 # Copyright 2005-2009 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -135,7 +135,15 @@ class SpeechGenerator(generator.Generator):
         'displayedText or name or description'). [[[JD to WDW - I
         needed a _generateDescription for whereAmI. :-) See below.
         """
-        acss = self.voice(DEFAULT)
+
+        role = args.get('role', obj.getRole())
+        if role == pyatspi.ROLE_LAYERED_PANE:
+            if settings.onlySpeakDisplayedText:
+                return []
+            else:
+                acss = self.voice(SYSTEM)
+        else:
+            acss = self.voice(DEFAULT)
         result = generator.Generator._generateName(self, obj, **args)
         if result:
             result.extend(acss)
@@ -1093,7 +1101,7 @@ class SpeechGenerator(generator.Generator):
                 newLine += " ; "
             newLine += attribs
 
-        result = [newline]
+        result = [newLine]
         result.extend(acss)
         return result
 
@@ -1617,7 +1625,9 @@ class SpeechGenerator(generator.Generator):
         specifications) that represent the relative position of an
         object in a list.
         """
-        if settings.onlySpeakDisplayedText:
+        if settings.onlySpeakDisplayedText \
+           or not (settings.enablePositionSpeaking \
+                   or args.get('forceList', False)):
             return []
 
         result = []
@@ -1687,9 +1697,7 @@ class SpeechGenerator(generator.Generator):
                 if nextName == name:
                     position = index
 
-        if (settings.enablePositionSpeaking \
-            or args.get('forceList', False)) \
-           and position >= 0:
+        if position >= 0:
             result.append(self._script.formatting.getString(
                               mode='speech',
                               stringType='groupindex') \
